@@ -30,7 +30,7 @@ wf_user_info <- function(
   }
 
   # get key from user
-  key <- wf_get_key(user)
+  key <- wf_get_key(user = user, service = "webapi")
 
   # query the status url provided
   response <- httr::GET(
